@@ -10,6 +10,7 @@ from derrick.core.rigging import Rigging
 from derrick.detectors.general.image_repo import ImageRepoDetector
 from derrick.detectors.image.golang import GolangVersionDetector
 from derrick.detectors.platform.golang.package_name import PackageNameDetector
+from derrick.detectors.general.derrick import DerrickDetector
 
 GOLANG = "Golang"
 
@@ -23,14 +24,22 @@ class GolangRigging(Rigging):
         return False, ""
 
     def compile(self, context):
-        dc = DetectorReport()
-        dn = dc.create_node("Dockerfile.j2")
+        dr = DetectorReport()
+        meta = dr.create_node("Meta")
+        meta.register_detector(ImageRepoDetector())
+
+        dn = dr.create_node("Dockerfile.j2")
         dn.register_detector(GolangVersionDetector())
         dn.register_detector(PackageNameDetector())
 
-        jn = dc.create_node("Jenkinsfile.j2")
+        jn = dr.create_node("Jenkinsfile.j2")
         jn.register_detector(ImageRepoDetector())
 
-        dcn = dc.create_node("docker-compose.yml.j2")
+        dcn = dr.create_node("docker-compose.yml.j2")
         dcn.register_detector(ImageRepoDetector())
-        return dc.generate_report()
+
+        derrick_deployment_file_node = dr.create_node("kubernetes-deployment.yaml.j2")
+        derrick_deployment_file_node.register_detector(ImageRepoDetector())
+        derrick_deployment_file_node.register_detector(DerrickDetector())
+
+        return dr.generate_report()
